#!/usr/bin/python
# C_waveform_envelope_display.py. D. Gibbon, 2021-07-06

import sys, re										# import specialised modules
import numpy as np
import matplotlib.pyplot as plt
import scipy.io.wavfile as wave
from scipy.signal import medfilt

if len(sys.argv) > 1:
	wavfilename = sys.argv[1]						# get input filename from command line 
else:
	wavfilename = "DATA/one-to-ten-Putonghua-Lara-16k-mono.wav"
wavfilebase = re.sub("^.*/","",wavfilename)
wavfilebase = re.sub("-16k-mono","",wavfilebase[:-4])
figurefilename = "PNG/C_%s.png"%wavfilebase

fs, signal = wave.read(wavfilename)					# read sampling frequency and signal
signallength = len(signal)							# define signal length in bytes
signalseconds = signallength / fs				# define signal length in seconds
signal = signal / max(abs(signal))					# normalise signal -1 ... 0 ... 1

envelope = medfilt(abs(signal), 301)
envelope = envelope / max(envelope)

#-----------------------------------------------------------------------------------------

plt.suptitle("%s, %d"%(wavfilename, fs), fontweight="bold")	# display a title

xaxis = np.linspace(0, signalseconds, signallength)			# define x axis in seconds

plt.plot(xaxis, signal, color="lightgrey")					# plot waveform in grey
plt.plot(xaxis, envelope, color="red")
plt.xlabel("Time")
plt.ylabel("Amplitude")
plt.xlim(0,np.ceil(signalseconds))

plt.tight_layout(pad=3)
plt.savefig(figurefilename)
plt.show()													# display figure
